@@ -26,7 +26,11 @@ class Escrow:
     
     #Creates an escrow holding address
     def createEscrow(self):
-        self.holdingAddress = self.api.get_new_addresses(count=None,checksum=True)['addresses'][0]
+        try:
+            self.holdingAddress = self.api.get_new_addresses(count=None,checksum=True)['addresses'][0]
+        except iota.adapter.BadApiResponse as e:
+            logging.warning("Bad response from server retrying.")
+            return self.createEscrow()
         return self.holdingAddress
 
     #Waits for a transactions with a refund address
@@ -112,7 +116,11 @@ class Escrow:
         ]
         
         #Send transaction
-        bundle = self.api.send_transfer(transfers=txs)['bundle']
+        try:
+            bundle = self.api.send_transfer(transfers=txs)['bundle']
+        except iota.adapter.BadApiResponse as e:
+            print("Node did not respond. Retrying.")
+            return self.finalizeEscrow(fee,deposit)
         logging.info(bundle.transactions[0].hash)
         logging.info("Sent money back to recipient")
         self.addRevenue(fee)
@@ -123,7 +131,7 @@ class Escrow:
             return response[0]
         except requests.exceptions.ConnectionError as e:
             logging.info("Error contacting server; retrying")
-            return getBalance(self,address)
+            return self.getBalance(self,address)
 
     #Record the amount of revenue recieved
     def addRevenue(self,money,filename='revenue.txt'):
